# gitlab

> A git, CI/CD, and project management platform using GitLab omnibus

<!-- metadata -->

* **Category**: Apps
* **Status**: 0
* **Image**: [`gitlab`](https://hub.docker.com/r/gitlab), 4, upstream
* **Healthcheck**: Yes
* **Backups**: Yes
* **Email**: No
* **Tests**: No
* **SSO**: 1 (OAuth)

<!-- endmetadata -->

## Quick start

- `abra app new gitlab --secrets`
- `abra app config <app-name>`
  - Set REGISTRY_DOMAIN to a domain that you want to use for the GitLab container registry (optional)
  - Set PAGES_DOMAIN to a domain that you want to use for the GitLab Pages service. NOTE: This cannot be a subdomain of the domain GitLab is hosted under. (optional)
  - Set GITLAB_ROOT_EMAIL to an appropriate email address
- `abra app deploy <app-name>`

## Accessing Git via SSH

GitLab is configured to accept ssh:// git connections on the non-standard port 2222. This is because by default the Coop Cloud host server also must accept SSH connections for server management, so port 22 is already occupied and can't be used by GitLab.

To allow Traefik to accept connections on port 2222, edit the configuration of your Traefik app:
`abra app config traefik.yourserver.com`
Uncomment the following section:
```
COMPOSE_FILE="$COMPOSE_FILE:compose.gitea.yml"
GITEA_SSH_ENABLED=1
```
Redeploy Traefik
`abra app undeploy traefik.yourserver.com`
`abra app deploy traefik.yourserver.com`

To configure your local git client to use the non-standard port by default, modify your local client's ~/.ssh/config file to include the following:
```
Host: git.yourserver.org
  Hostname: git.yourserver.org
  Port 2222
```

## Management Commands
The following commands for managing GitLab are available by running `abra app command <your gitlab app> app <command>`

`disable_basic_login` - Disables standard email/password based login to the server (for example, to allow only SSO login)

`enable_basic_login` - Re-enables standard email/password based login (enabled by default)

`disable_signups` - Prevents public signups to create accounts on the server

`enable_signups` - Re-enables public signups (signups are enabled by default)

`run_rails_command` - Run a command on GitLab's rails console. For more information: https://docs.gitlab.com/ee/administration/operations/rails_console.html

`reconfigure` - Reload the GitLab configuration (usually necessary after using `run_rails_command`)

## SSO Configuration

- Create a Provider and Application in Authentik: https://docs.goauthentik.io/integrations/services/gitlab/#openid-connect-auth
    - Note the Provider ID and Secret
- Run `abra app config <app-name>`
    - Uncomment the Authentik Configuration config block
    - Set `SSO_PROVIDER_ID` to the Authentik Provider ID
- Run `abra app secret insert <app-name> sso_provider_secret v1 <Authentik Provider Secret>`

For more, see [`docs.coopcloud.tech`](https://docs.coopcloud.tech).